@@ -210,6 +210,7 @@ cffi_ffierror simple_service_result(cffi_simpleservice* context_ptr, uint32_t x)
 uint32_t simple_service_value(cffi_simpleservice* context_ptr, uint32_t x);
 uint8_t simple_service_mut_self(cffi_simpleservice* context_ptr, cffi_ffisliceu8 slice);
 void simple_service_mut_self_void(cffi_simpleservice* context_ptr, cffi_ffisliceu8 slice);
+uint8_t simple_service_mut_self_ref(cffi_simpleservice* context_ptr, uint8_t* x, uint8_t* _y);
 cffi_ffierror simple_service_mut_self_ffi_error(cffi_simpleservice* context_ptr, cffi_ffisliceu8 slice);
 void simple_service_void(cffi_simpleservice* context_ptr);
 uint32_t simple_service_extra_method(cffi_simpleservice* _context);
@@ -1130,6 +1131,17 @@ This function may only be called with a context returned by a succeeding `patter
             slice = slice._ctx[0]
         return _api.simple_service_mut_self_void(context_ptr, slice)
 
+    def simple_service_mut_self_ref(context_ptr, x, _y):
+        """"""
+        global _api
+        if hasattr(context_ptr, "_ctx"):
+            context_ptr = context_ptr._ctx[0]
+        if hasattr(x, "_ctx"):
+            x = x._ctx[0]
+        if hasattr(_y, "_ctx"):
+            _y = _y._ctx[0]
+        return _api.simple_service_mut_self_ref(context_ptr, x, _y)
+
     def simple_service_mut_self_ffi_error(context_ptr, slice):
         """"""
         global _api
@@ -1248,6 +1260,11 @@ class SimpleService(object):
         global raw
         return _api.simple_service_mut_self_void(self.ctx[0], slice)
 
+    def mut_self_ref(self, x, _y):
+        """"""
+        global raw
+        return _api.simple_service_mut_self_ref(self.ctx[0], x, _y)
+
     def mut_self_ffi_error(self, slice):
         """"""
         global raw
